@@ -3,14 +3,13 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 #include "topfisheyeview.h"
-
+#include <cgraph/alloc.h>
 #include <math.h>
-#include <common/memory.h>
 #include "viewport.h"
 #include "viewportcamera.h"
 #include "draw.h"
@@ -23,10 +22,6 @@
 #include <common/color.h>
 #include <common/colorprocs.h>
 
-#ifdef _WIN32
-#include <wincrypt.h>
-#endif
-
 static int get_temp_coords(topview * t, int level, int v, double *coord_x,
 			   double *coord_y);
 
@@ -54,9 +49,9 @@ static v_data *makeGraph(Agraph_t* gg, int *nedges)
     int i;
     int ne = agnedges(gg);
     int nv = agnnodes(gg);
-    v_data *graph = N_NEW(nv, v_data);
-    int *edges = N_NEW(2 * ne + nv, int);	/* reserve space for self loops */
-    float *ewgts = N_NEW(2 * ne + nv, float);
+    v_data *graph = gv_calloc(nv, sizeof(v_data));
+    int *edges = gv_calloc(2 * ne + nv, sizeof(int));	/* reserve space for self loops */
+    float *ewgts = gv_calloc(2 * ne + nv, sizeof(float));
     Agnode_t *np;
     Agedge_t *ep;
     Agraph_t *g = NULL;
@@ -126,8 +121,8 @@ static void refresh_old_values(topview * t)
  */
 void prepare_topological_fisheye(Agraph_t* g,topview * t)
 {
-    double *x_coords = N_NEW(t->Nodecount, double);	// initial x coordinates
-    double *y_coords = N_NEW(t->Nodecount, double);	// initial y coordinates
+    double *x_coords = gv_calloc(t->Nodecount, sizeof(double));	// initial x coordinates
+    double *y_coords = gv_calloc(t->Nodecount, sizeof(double));	// initial y coordinates
     focus_t *fs;
     int ne;
     int i;
@@ -165,7 +160,6 @@ void prepare_topological_fisheye(Agraph_t* g,topview * t)
 	(int) (view->bdxRight - view->bdxLeft);
     view->Topview->fisheyeParams.repos.height =
 	(int) (view->bdyTop - view->bdyBottom);
-    view->Topview->fisheyeParams.repos.rescale = Polar;
 
     //topological fisheye
 
@@ -239,10 +233,9 @@ static void drawtopfishnodes(topview * t)
 		    max_visible_level = level;
 		color_interpolation(srcColor, tarColor, &color,
 				    max_visible_level, level);
-		glColor4f(color.R, color.G, color.B,
-			  (GLfloat) view->defaultnodealpha);
+		glColor4f(color.R, color.G, color.B, view->defaultnodealpha);
 
-		glVertex3f((GLfloat) x0, (GLfloat) y0, 0.0f);
+		glVertex3f((float)x0, (float)y0, 0.0f);
 	    }
 	}
     }
@@ -282,13 +275,11 @@ static void drawtopfishedges(topview * t)
 			max_visible_level = level;
 		    color_interpolation(srcColor, tarColor, &color,
 					max_visible_level, level);
-		    glColor4f(color.R, color.G, color.B,
-			      (GLfloat) view->defaultnodealpha);
-
+		    glColor4f(color.R, color.G, color.B, view->defaultnodealpha);
 
 		    if (get_temp_coords(t, level, n, &x, &y)) {
-			glVertex3f((GLfloat) x0, (GLfloat) y0, 0.0f);
-			glVertex3f((GLfloat) x, (GLfloat) y, 0.0f);
+			glVertex3f((float)x0, (float)y0, 0.0f);
+			glVertex3f((float)x, (float)y, 0.0f);
 		    } else
 		    {
 			int levell, nodee;
@@ -296,21 +287,20 @@ static void drawtopfishedges(topview * t)
 						  &nodee);
 			if (get_temp_coords(t, levell, nodee, &x, &y)) {
 
-			    if ((!(((-x0 / view->zoom > view->clipX1)
-				    && (-x0 / view->zoom < view->clipX2)
-				    && (-y0 / view->zoom > view->clipY1)
-				    && (-y0 / view->zoom < view->clipY2))))
-				&& (!(((-x / view->zoom > view->clipX1)
-				       && (-x / view->zoom < view->clipX2)
-				       && (-y / view->zoom > view->clipY1)
-				       && (-y / view->zoom <
-					   view->clipY2)))))
+			    if (!(-x0 / view->zoom > view->clipX1
+				    && -x0 / view->zoom < view->clipX2
+				    && -y0 / view->zoom > view->clipY1
+				    && -y0 / view->zoom < view->clipY2)
+				&& !(-x / view->zoom > view->clipX1
+				       && -x / view->zoom < view->clipX2
+				       && -y / view->zoom > view->clipY1
+				       && -y / view->zoom < view->clipY2))
 
 				continue;
 
 
-			    glVertex3f((GLfloat) x0, (GLfloat) y0, 0.0f);
-			    glVertex3f((GLfloat) x, (GLfloat) y, 0.0f);
+			    glVertex3f((float)x0, (float)y0, 0.0f);
+			    glVertex3f((float)x, (float)y, 0.0f);
 			}
 		    }
 		}
