@@ -1,18 +1,23 @@
+/// @file
+/// @ingroup common_render
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#include <cgraph/alloc.h>
 #include <cgraph/agxbuf.h>
+#include <cgraph/prisize_t.h>
 #include <cgraph/unreachable.h>
 #include <common/render.h>
 #include <label/xlabels.h>
 #include <stdbool.h>
+#include <stddef.h>
 
 static int Rankdir;
 static bool Flip;
@@ -88,18 +93,17 @@ static pointf map_point(pointf p)
 
 static void map_edge(edge_t * e)
 {
-    int j, k;
     bezier bz;
 
     if (ED_spl(e) == NULL) {
 	if (!Concentrate && ED_edge_type(e) != IGNORED)
-	    agerr(AGERR, "lost %s %s edge\n", agnameof(agtail(e)),
+	    agerrorf("lost %s %s edge\n", agnameof(agtail(e)),
 		  agnameof(aghead(e)));
 	return;
     }
-    for (j = 0; j < ED_spl(e)->size; j++) {
+    for (size_t j = 0; j < ED_spl(e)->size; j++) {
 	bz = ED_spl(e)->list[j];
-	for (k = 0; k < bz.size; k++)
+	for (size_t k = 0; k < bz.size; k++)
 	    bz.list[k] = map_point(bz.list[k]);
 	if (bz.sflag)
 	    ED_spl(e)->list[j].sp = map_point(ED_spl(e)->list[j].sp);
@@ -110,7 +114,6 @@ static void map_edge(edge_t * e)
 	ED_label(e)->pos = map_point(ED_label(e)->pos);
     if (ED_xlabel(e))
 	ED_xlabel(e)->pos = map_point(ED_xlabel(e)->pos);
-    /* vladimir */
     if (ED_head_label(e))
 	ED_head_label(e)->pos = map_point(ED_head_label(e)->pos);
     if (ED_tail_label(e))
@@ -189,7 +192,7 @@ static void place_root_label(graph_t * g, pointf d)
     }
 
     GD_label(g)->pos = p;
-    GD_label(g)->set = TRUE;
+    GD_label(g)->set = true;
 }
 
 /* centerPt:
@@ -207,31 +210,29 @@ centerPt (xlabel_t* xlp) {
   return p;
 }
 
-static int
-printData (object_t* objs, int n_objs, xlabel_t* lbls, int n_lbls,
-	   label_params_t* params) {
-  int i;
+static void printData(object_t *objs, size_t n_objs, xlabel_t *lbls,
+                      size_t n_lbls, label_params_t *params) {
   xlabel_t* xp;
-  fprintf (stderr, "%d objs %d xlabels force=%d bb=(%.02f,%.02f) (%.02f,%.02f)\n",
+  fprintf (stderr, "%" PRISIZE_T " objs %" PRISIZE_T
+	   " xlabels force=%d bb=(%.02f,%.02f) (%.02f,%.02f)\n",
 	   n_objs, n_lbls, params->force, params->bb.LL.x, params->bb.LL.y,
 	   params->bb.UR.x, params->bb.UR.y);
-  if (Verbose < 2) return 0;
+  if (Verbose < 2) return;
   fprintf(stderr, "objects\n");
-  for (i = 0; i < n_objs; i++) {
+  for (size_t i = 0; i < n_objs; i++) {
     xp = objs->lbl;
-    fprintf(stderr, " [%d] (%.02f,%.02f) (%.02f,%.02f) %p \"%s\"\n",
+    fprintf(stderr, " [%" PRISIZE_T "] (%.02f,%.02f) (%.02f,%.02f) %p \"%s\"\n",
             i, objs->pos.x, objs->pos.y, objs->sz.x, objs->sz.y, objs->lbl,
             xp ? ((textlabel_t*)xp->lbl)->text : "");
     objs++;
   }
   fprintf(stderr, "xlabels\n");
-  for (i = 0; i < n_lbls; i++) {
-    fprintf(stderr, " [%d] %p set %d (%.02f,%.02f) (%.02f,%.02f) %s\n",
+  for (size_t i = 0; i < n_lbls; i++) {
+    fprintf(stderr, " [%" PRISIZE_T "] %p set %d (%.02f,%.02f) (%.02f,%.02f) %s\n",
             i, lbls, lbls->set, lbls->pos.x, lbls->pos.y, lbls->sz.x,
             lbls->sz.y, ((textlabel_t*)lbls->lbl)->text);
     lbls++;
   }
-  return 0;
 }
 
 static pointf
@@ -383,13 +384,11 @@ addClusterObj (Agraph_t* g, cinfo_t info)
     return info;
 }
 
-static int
-countClusterLabels (Agraph_t* g)
-{
-    int c, i = 0;
+static size_t countClusterLabels(Agraph_t *g) {
+    size_t i = 0;
     if (g != agroot(g) && GD_label(g) && GD_label(g)->set)
 	i++;
-    for (c = 1; c <= GD_n_cluster(g); c++)
+    for (int c = 1; c <= GD_n_cluster(g); c++)
 	i += countClusterLabels (GD_clust(g)[c]);
     return i;
 }
@@ -407,18 +406,15 @@ static void addXLabels(Agraph_t * gp)
 {
     Agnode_t *np;
     Agedge_t *ep;
-    int cnt, i, n_objs, n_lbls;
-    int n_nlbls = 0;		/* # of unset node xlabels */
-    int n_elbls = 0;		/* # of unset edge labels or xlabels */
-    int n_set_lbls = 0;		/* # of set xlabels and edge labels */
-    int n_clbls = 0;		/* # of set cluster labels */
+    size_t n_nlbls = 0; // # of unset node xlabels
+    size_t n_elbls = 0; // # of unset edge labels or xlabels
+    size_t n_set_lbls = 0; // # of set xlabels and edge labels
+    size_t n_clbls = 0; // # of set cluster labels
     boxf bb;
     textlabel_t* lp;
     label_params_t params;
     object_t* objs;
     xlabel_t* lbls;
-    object_t* objp;
-    xlabel_t* xlp;
     Agsym_t* force;
     int et = EDGE_TYPE(gp);
 
@@ -467,15 +463,15 @@ static void addXLabels(Agraph_t * gp)
 	n_clbls = countClusterLabels (gp);
 
     /* A label for each unpositioned external label */
-    n_lbls = n_nlbls + n_elbls;
+    size_t n_lbls = n_nlbls + n_elbls;
     if (n_lbls == 0) return;
 
     /* An object for each node, each positioned external label, any cluster label, 
      * and all unset edge labels and xlabels.
      */
-    n_objs = agnnodes(gp) + n_set_lbls + n_clbls + n_elbls;
-    objp = objs = N_NEW(n_objs, object_t);
-    xlp = lbls = N_NEW(n_lbls, xlabel_t);
+    size_t n_objs = (size_t)agnnodes(gp) + n_set_lbls + n_clbls + n_elbls;
+    object_t* objp = objs = gv_calloc(n_objs, sizeof(object_t));
+    xlabel_t* xlp = lbls = gv_calloc(n_lbls, sizeof(xlabel_t));
     bb.LL = (pointf){INT_MAX, INT_MAX};
     bb.UR = (pointf){-INT_MAX, -INT_MAX};
 
@@ -504,7 +500,7 @@ static void addXLabels(Agraph_t * gp)
 		    xlp++;
 		}
 		else {
-		    agerr(AGWARN, "no position for edge with label %s\n",
+		    agwarningf("no position for edge with label %s\n",
 			    ED_label(ep)->text);
 		    continue;
 		}
@@ -519,7 +515,7 @@ static void addXLabels(Agraph_t * gp)
 		    xlp++;
 		}
 		else {
-		    agerr(AGWARN, "no position for edge with tail label %s\n",
+		    agwarningf("no position for edge with tail label %s\n",
 			    ED_tail_label(ep)->text);
 		    continue;
 		}
@@ -534,7 +530,7 @@ static void addXLabels(Agraph_t * gp)
 		    xlp++;
 		}
 		else {
-		    agerr(AGWARN, "no position for edge with head label %s\n",
+		    agwarningf("no position for edge with head label %s\n",
 			    ED_head_label(ep)->text);
 		    continue;
 		}
@@ -549,7 +545,7 @@ static void addXLabels(Agraph_t * gp)
 		    xlp++;
 		}
 		else {
-		    agerr(AGWARN, "no position for edge with xlabel %s\n",
+		    agwarningf("no position for edge with xlabel %s\n",
 			    ED_xlabel(ep)->text);
 		    continue;
 		}
@@ -574,8 +570,8 @@ static void addXLabels(Agraph_t * gp)
 	printData(objs, n_objs, lbls, n_lbls, &params);
 
     xlp = lbls;
-    cnt = 0;
-    for (i = 0; i < n_lbls; i++) {
+    size_t cnt = 0;
+    for (size_t i = 0; i < n_lbls; i++) {
 	if (xlp->set) {
 	    cnt++;
 	    lp = (textlabel_t *)xlp->lbl;
@@ -586,9 +582,11 @@ static void addXLabels(Agraph_t * gp)
 	xlp++;
     }
     if (Verbose)
-	fprintf (stderr, "%d out of %d labels positioned.\n", cnt, n_lbls);
+	fprintf(stderr, "%" PRISIZE_T " out of %" PRISIZE_T " labels positioned.\n",
+	        cnt, n_lbls);
     else if (cnt != n_lbls)
-	agerr(AGWARN, "%d out of %d exterior labels positioned.\n", cnt, n_lbls);
+	agwarningf("%" PRISIZE_T " out of %" PRISIZE_T " exterior labels positioned.\n",
+	      cnt, n_lbls);
     free(objs);
     free(lbls);
 }
@@ -679,14 +677,14 @@ void gv_postprocess(Agraph_t * g, int allowTranslation)
     if (GD_label(g) && !GD_label(g)->set)
 	place_root_label(g, dimen);
 
-    if (Show_boxes) {
+    if (!show_boxes_is_empty(&Show_boxes)) {
 	agxbuf buf = {0};
 	if (Flip)
 	    agxbprint(&buf, M2, Offset.x, Offset.y, Offset.x, Offset.y);
 	else
 	    agxbprint(&buf, M1, Offset.y, Offset.x, Offset.y, Offset.x,
 		    -Offset.x, -Offset.y);
-	Show_boxes[0] = agxbdisown(&buf);
+	show_boxes_append(&Show_boxes, agxbdisown(&buf));
     }
 }
 
@@ -722,7 +720,7 @@ static void place_flip_graph_label(graph_t * g)
 	    p.y = (GD_bb(g).LL.y + GD_bb(g).UR.y) / 2;
 	}
 	GD_label(g)->pos = p;
-	GD_label(g)->set = TRUE;
+	GD_label(g)->set = true;
     }
 
     for (c = 1; c <= GD_n_cluster(g); c++)
